/**
 * Copyright 2011-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.plugin.mergeproperties.core;

import java.util.List;
import java.util.regex.Pattern;

/**
 * This class represents an aggregate strategy
 * With an aggregate strategy, we aggregate all value of a key with ',' character
 *
 * @author Jeremy Cazaux
 */
public class AggregateStrategy implements FilteringStrategy {

    /**
     * @parameter key of the aggregate strategy
     */
    private String key;

    /**
     * Pattern object of the key
     */
    private Pattern pattern;

    /**
     * Default constructor
     */
    public AggregateStrategy() {
    }

    /**
     * Execute the strategy
     * @param key
     * @param values
     * @return the property
     */
    public String execute(final String key, final List<String> values, final String separator) {
        StringBuilder line = new StringBuilder();
        if (values.size() == 0 && separator == null) {
            line.append(key);
            return line.toString();
        } else {
            line.append(key).append(separator);
            for (String value:values) {
                line.append(value).append(",");
            }
            return line.toString().substring(0, line.length() - 1);
        }
    }

    /**
     * Initialize the pattern
     */
    public void initPattern() {
        this.pattern = Pattern.compile(this.key);
    }

    /**
     * @param s
     * @return true if s match pattern; false otherwise.
     */
    public boolean matchPattern(final String s) {
        return pattern.matcher(s).matches();
    }

    /**
     *
     * @return the key
     */
    public String getKey() {
        return key;
    }

    /**
     *
     * @return the pattern
     */
    public Pattern getPattern() {
        return pattern;
    }

    /**
     *
     * @param key The key to set
     */
    public void setKey(String key) {
        this.key = key;
    }

    /**
     *
     * @param pattern The pattern to set
     */
    public void setPattern(Pattern pattern) {
        this.pattern = pattern;
    }
}
