/**
 * Copyright 2011-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.plugin.mergeproperties.core;

import java.util.List;
import java.util.regex.Pattern;

/**
 * This class represents an exclusive strategy
 * With an exclusive strategy, we keep the first property ( association of key and values) and we add a '#' before
 * others properties with the same key
 *
 * @author Jeremy Cazaux
 */
public class ExclusiveStrategy  implements FilteringStrategy {

    /**
     * @parameter key of the exclusive strategy
     */
    private String key;

    /**
     * Pattern object of the key
     */
    private Pattern pattern;

    /**
     * End of line
     */
    private static final String EOL = "\n";

    /**
     * Default constructor
     */
    public ExclusiveStrategy() {
    }

    /**
     * Execute the strategy
     * @param key
     * @param values
     * @return the property
     */
    public String execute(final String key, final List<String> values, final String separator) {
        StringBuilder line = new StringBuilder();
        int i = 0;
         while (i < values.size()){
            if (i == 0) {
                line.append(key).append(separator).append(values.get(i));
                if (i < values.size() - 1) {
                    line.append(EOL);
                }
            } else if (i <values.size()-1) {
                line.append("#").append(key).append(separator).append(values.get(i)).append(EOL);
             } else {
                line.append("#").append(key).append(separator).append(values.get(i));
             }
             i++;
         }
        return line.toString();
    }

    /**
     * Initialize the pattern
     */
    public void initPattern() {
        this.pattern = Pattern.compile(this.key);
    }

    /**
     * @param s
     * @return true if s match pattern; false otherwise.
     */
    public boolean matchPattern(final String s) {
        return pattern.matcher(s).matches();
    }

    /**
     *
     * @param key The key to set
     */
    public void setKey(String key) {
        this.key = key;
    }

    /**
     *
     * @param pattern The pattern to set
     */
    public void setPattern(Pattern pattern) {
        this.pattern = pattern;
    }
}
