/**
 * Copyright 2011-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.plugin.mergeproperties.core;

import java.util.ArrayList;
import java.util.List;

/**
 * This class represents a Marker.
 * A marker is an association of key and values to insert in a template file in order to replace a marked property.
 * A marked property is a string delimited by '%' character (for example "%marked_property%") in a template file.
 * @author Jeremy Cazaux
 */
public class Marker {

    /**
     * Key of the property
     */
    private final String key;

    /**
     * Values of the property
     */
    private List<String> values;

    /**
     * Separator
     */
    private String separator;

    /**
     * True if the marker has been written into the output input stream
     */
    private boolean isWrite;

    /**
     * Default constructor.
     * @param key ,the key of the property
     */
    public Marker(final String key) {
        this.key = key;
        this.values = new ArrayList<String>();
        this.isWrite = false;
    }

    /**
     * @return the key of the property
     */
    public String getKey() {
        return this.key;
    }

    /**
     * Add a value to the list of values associated to the key
     * @param value
     */
    public void addValue(final String value) {
        this.values.add(value);
    }

    /**
     * @return values associated  to the key
     */
    public List getValues() {
        return this.values;
    }

    /**
     *
     * @param separator Separator to set
     */
    public void setSeparator(String separator) {
        this.separator = separator;
    }

    /**
     *
     * @return the separator
     */
    public String getSeparator() {
        return separator;
    }

    /*
     * @return true if the marker has been written
     */
    public boolean isWrite() {
        return isWrite;
    }

    /**
     * @param write Set if the marker has been written
     */
    public void setWrite(boolean write) {
        isWrite = write;
    }
}
