/**
 * Copyright 2011-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.plugin.mergeproperties.core;

import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * This class represents an Order or fixed preference
 * @author Jeremy Cazaux
 */
public class Preference {

    /**
     * Key of the preference property
     * @parameter
     * @required
     */
    private String key;

    /**
     * Values of the preference property
     * @parameter
     * @required
     */
    private String values;

    /**
     *  Pattern object of the key
     */
    private Pattern pattern;

    /**
     * The first item in the list has the highest priority
     */
    private List<String> listValues;

    /**
     * Default constructor
     */
    public Preference() {
    }

    /**
     * @return the key
     */
    public String getKey() {
        return this.key;
    }

    /**
     * @return the list of values as a list. Initialize the list if the list is null.
     */
    public List<String> getListValues() {
        if (this.listValues == null) {
            initValues();
        }
        return this.listValues;
    }

    /**
     * Add a value  to the list of values
     * @param value
     */
    public void addValue(final String value) {
        this.listValues.add(value);
    }

    /**
     * Initialize listValues with values element
     */
    public void initValues() {
        this.listValues = new ArrayList<String>();
        StringTokenizer stringTokenizer = new StringTokenizer(this.values, ",");

        while(stringTokenizer.hasMoreElements()) {
            listValues.add(stringTokenizer.nextElement().toString());
        }
    }

    /**
     * initialize Pattern object with the key parameter
     */
    public void initPattern() {
        this.pattern = Pattern.compile(this.key);
    }

    /**
     * Test if a string match the pattern
     * @param s
     * @return true if s match pattern; false otherwise.
     */
    public boolean matchPattern(final String s) {
        Matcher matcher = this.pattern.matcher(s);
        return matcher.matches();
    }

    /**
     *
     * @param key The key to set
     */
    public void setKey(String key) {
        this.key = key;
    }

    /**
     *
     * @param values Values to set
     */
    public void setValues(String values) {
        this.values = values;
    }
}
