/**
 * Copyright 2011-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.plugin.mergeproperties.core;

import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;

import org.codehaus.plexus.util.IOUtil;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Resource
 * @author Jeremy Cazaux
 */
public class Resource {

    /**
     * The original InputStream
     */
    private byte[] originalInputStream;

    /**
     * The BufferedReader of the resource
     */
    private BufferedReader bufferedReader;

    /**
     * The InputStreamReader of the resource
     */
    private InputStreamReader inputStreamReader;

    /**
     * The name of the resource
     */
    private String name;

    /**
     * Logger
     */
    protected Log logger = LogFactory.getLog(this.getClass());

    /**
     * Default constructor
     */
    public Resource(final InputStream inputStream) {
        try {
            this.originalInputStream = IOUtil.toByteArray(inputStream);
        } catch (IOException e) {
            logger.error("Cannot duplicate the inputstream");
        }
    }

    /**
     * @return a copy of the original inputstream of the resource
     */
    public InputStream getInputStream() {
        return new ByteArrayInputStream(this.originalInputStream);
    }

    /**
     * @return a new BufferedReader of the resource
     */
    public BufferedReader getBufferedReader() {

        //close all resources if they are opened
        close();

        //get a new BufferReader of the resource
        this.inputStreamReader = new InputStreamReader(getInputStream());
        this.bufferedReader = new BufferedReader(this.inputStreamReader);

        return this.bufferedReader;
    }

    /**
     *
     * @return the name of the resource
     */
    public String getName() {
        return name;
    }

    /**
     *
     * @param name The name of the resource to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Close all streams of the resource
     */
    public void close() {

        if (this.inputStreamReader != null) {
            try {
                this.inputStreamReader.close();
            } catch (IOException e) {
                this.logger.debug("Cannot close the InputStreamReader of the resource " + this.name + " ." , e);
            }
        }

        if (this.bufferedReader != null) {
            try {
                this.bufferedReader.close();
            } catch (IOException e) {
                this.logger.debug("Cannot close the BufferedReader of the resource " + this.name + " ." , e);
            }
        }
    }
}
