/**
 * Copyright 2011-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.plugin.mergeproperties.core;

/**
 * This class represents a file order preference.
 * @author Jeremy Cazaux
 */
public class ResourceOrderPreference {

    /**
     * Priority of the file.
     */
    private int priority;

    /**
     * Resource
     */
    private Resource resource;

    /**
     *  The most common keys subsequence of the file
     */
    private String mostCommonSubKey;

    /**
     * Default constructor
     * @param priority of the file
     * @param resource The resource
     * @param mostCommonSubKey the most common keys subsequence of the file
     */
    public ResourceOrderPreference(final int priority, final Resource resource, final String mostCommonSubKey) {
        this.priority = priority;
        this.resource = resource;
        this.mostCommonSubKey = mostCommonSubKey;
    }

    /**
     * @return the resource
     */
    public Resource getResource() {
        return this.resource;
    }

    /**
     * @return the most common key subsequence of the file
     */
    public String getMostCommonSubKey() {
        return this.mostCommonSubKey;
    }

    /**
     * @return the priority associated to the file
     */
    public int getPriority() {
        return this.priority;
    }

    /**
     * @param resource The name of the file to set
     */
    public void setResource(final Resource resource) {
        this.resource = resource;
    }

    /**
     * @param mostCommonSubKey The most common key subsequence of the file to set
     */
    public void setMostCommonSubKey(final String mostCommonSubKey) {
        this.mostCommonSubKey = mostCommonSubKey;
    }

    /**
     * @param priority The priority of the file to set
     */
    public void setPriority(final int priority) {
        this.priority = priority;
    }
}
