/**
 * Copyright 2011-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.plugin.mergeproperties.core;

import java.io.Serializable;
import java.util.Comparator;

/**
 * This class represents a comparator for ResourceOrderPreference Class
 * @author Jeremy Cazaux
 */
public class ResourceOrderPreferenceComparator implements Serializable, Comparator<ResourceOrderPreference> {

    /**
     *
     * @param resourceOrderPreference1
     * @param resourceOrderPreference2
     * @return a negative integer, zero, or a positive integer as the first argument is less than, equal to, or greater
     * than the second.
     */
    public int compare(final ResourceOrderPreference resourceOrderPreference1, final ResourceOrderPreference resourceOrderPreference2) {

        if (resourceOrderPreference1.getPriority() > resourceOrderPreference2.getPriority()) {
            return -1;
        } else if (resourceOrderPreference1.getPriority() < resourceOrderPreference2.getPriority()) {
            return 1;
        } else {

            final String mostCommonSubKey1 = resourceOrderPreference1.getMostCommonSubKey();
            final String mostCommonSubKey2 = resourceOrderPreference2.getMostCommonSubKey();
            final String filename1 = resourceOrderPreference1.getResource().getName();
            final String filename2 = resourceOrderPreference2.getResource().getName();

            //if there is a template and properties resource with a common subsequence, template resource need to be put
            // before the properties file
            if ((mostCommonSubKey1.length() <= mostCommonSubKey2.length() &&
                 (mostCommonSubKey2.substring(0, mostCommonSubKey1.length()).equals(mostCommonSubKey1))) ||

                 (mostCommonSubKey1.length() > mostCommonSubKey2.length() &&
                 (mostCommonSubKey1.substring(0, mostCommonSubKey2.length()).equals(mostCommonSubKey2)))
            ){
                if (filename1.endsWith(".properties") && filename2.endsWith(".template")) {
                    return 1;
                } else if (filename2.endsWith(".properties") && filename1.endsWith(".template")) {
                    return -1;
                }
            }

            return resourceOrderPreference1.getMostCommonSubKey().compareTo(resourceOrderPreference2.getMostCommonSubKey());

        }
    }
}
